@@ -4,28 +4,40 @@ use owo_colors::AnsiColors::{Black, Green, Red, Yellow};
 use owo_colors::OwoColorize;
 use std::fmt::Write;
 
-pub(crate) fn diff_line_result(line: &LineResult) -> String {
+/// Diff a LineResult with colorize output.
+pub(crate) fn diff_line_result(line: &LineResult, no_diff_bg_color: bool) -> String {
     let mut err_color = Red;
     if line.severity.is_warning() {
         err_color = Yellow;
     }
 
-    diff_lines_with_err_color(line.old.trim(), line.new.trim(), err_color)
+    let on_color = match no_diff_bg_color {
+        true => on_color_transparent,
+        false => on_color,
+    };
+
+    diff_lines_with_err_color(line.old.trim(), line.new.trim(), err_color, on_color)
 }
 
 #[allow(dead_code)]
 pub(crate) fn diff_lines(old_str: &str, new_str: &str) -> String {
-    diff_lines_with_err_color(old_str, new_str, Red)
+    diff_lines_with_err_color(old_str, new_str, Red, on_color)
 }
 
+type OnColorFn = fn(s: char, color: owo_colors::AnsiColors) -> String;
+
+#[inline]
 fn on_color(s: char, color: owo_colors::AnsiColors) -> String {
-    // if s == ' ' {
-    //     return format!("{}", s.blink_fast().color(color));
-    // }
     let t = s.on_color(color).color(Black);
     format!("{}", t)
 }
 
+#[inline]
+fn on_color_transparent(s: char, color: owo_colors::AnsiColors) -> String {
+    let t = s.color(color);
+    format!("{}", t)
+}
+
 // Screenshot:
 // https://raw.githubusercontent.com/johannhof/difference.rs/master/assets/github-style.png
 // https://github.com/johannhof/difference.rs/blob/master/examples/github-style.rs
@@ -34,6 +46,7 @@ pub(crate) fn diff_lines_with_err_color(
     old_str: &str,
     new_str: &str,
     err_color: owo_colors::AnsiColors,
+    on_color: OnColorFn,
 ) -> String {
     let diffs = diff::lines(old_str, new_str);
 
@@ -42,7 +55,9 @@ pub(crate) fn diff_lines_with_err_color(
     for i in 0..diffs.len() {
         match diffs[i] {
             diff::Result::Both(x, _) => {
-                writeln!(out, " {}", x);
+                out.push(' ');
+                out.push_str(x);
+                out.push('\n');
             }
             // -
             diff::Result::Left(x) => {
@@ -61,7 +76,7 @@ pub(crate) fn diff_lines_with_err_color(
                                 _ => (),
                             }
                         }
-                        writeln!(out);
+                        out.push('\n');
                     }
                     _ => {
                         writeln!(out, "{}", format!("-{}", x).color(err_color));
@@ -86,7 +101,7 @@ pub(crate) fn diff_lines_with_err_color(
                                 _ => (),
                             }
                         }
-                        writeln!(out);
+                        out.push('\n');
                     }
                     _ => {
                         writeln!(out, "{}", format!("+{}", x).color(Green));
@@ -97,7 +112,7 @@ pub(crate) fn diff_lines_with_err_color(
     }
 
     // leave a blank line between each diff
-    writeln!(out);
+    out.push('\n');
 
     out
 }
@@ -110,18 +125,24 @@ mod tests {
     #[test]
     fn test_color_output() {
         let old_str = " Hello你好 ";
-        let new_str = "Hello 你好";
-        let mut diff = diff_lines_with_err_color(old_str, new_str, Red);
+        let new_str = "Hallo 你好";
 
+        let diff = diff_lines_with_err_color(old_str, new_str, Red, on_color);
         assert_eq!(
-            "\u{1b}[31m-\u{1b}[39m\u{1b}[30;41m \u{1b}[0m\u{1b}[31mH\u{1b}[39m\u{1b}[31me\u{1b}[39m\u{1b}[31ml\u{1b}[39m\u{1b}[31ml\u{1b}[39m\u{1b}[31mo\u{1b}[39m\u{1b}[31m你\u{1b}[39m\u{1b}[31m好\u{1b}[39m\u{1b}[30;41m \u{1b}[0m\n\u{1b}[32m+\u{1b}[39m\u{1b}[32mH\u{1b}[39m\u{1b}[32me\u{1b}[39m\u{1b}[32ml\u{1b}[39m\u{1b}[32ml\u{1b}[39m\u{1b}[32mo\u{1b}[39m\u{1b}[30;42m \u{1b}[0m\u{1b}[32m你\u{1b}[39m\u{1b}[32m好\u{1b}[39m\n\n",
+            "\u{1b}[31m-\u{1b}[39m\u{1b}[30;41m \u{1b}[0m\u{1b}[31mH\u{1b}[39m\u{1b}[30;41me\u{1b}[0m\u{1b}[31ml\u{1b}[39m\u{1b}[31ml\u{1b}[39m\u{1b}[31mo\u{1b}[39m\u{1b}[31m你\u{1b}[39m\u{1b}[31m好\u{1b}[39m\u{1b}[30;41m \u{1b}[0m\n\u{1b}[32m+\u{1b}[39m\u{1b}[32mH\u{1b}[39m\u{1b}[30;42ma\u{1b}[0m\u{1b}[32ml\u{1b}[39m\u{1b}[32ml\u{1b}[39m\u{1b}[32mo\u{1b}[39m\u{1b}[30;42m \u{1b}[0m\u{1b}[32m你\u{1b}[39m\u{1b}[32m好\u{1b}[39m\n\n",
             diff
         );
 
-        diff = diff_lines_with_err_color(old_str, new_str, Yellow);
+        let diff = diff_lines_with_err_color(old_str, new_str, Yellow, on_color);
         assert_eq!(
-            "\u{1b}[33m-\u{1b}[39m\u{1b}[30;43m \u{1b}[0m\u{1b}[33mH\u{1b}[39m\u{1b}[33me\u{1b}[39m\u{1b}[33ml\u{1b}[39m\u{1b}[33ml\u{1b}[39m\u{1b}[33mo\u{1b}[39m\u{1b}[33m你\u{1b}[39m\u{1b}[33m好\u{1b}[39m\u{1b}[30;43m \u{1b}[0m\n\u{1b}[32m+\u{1b}[39m\u{1b}[32mH\u{1b}[39m\u{1b}[32me\u{1b}[39m\u{1b}[32ml\u{1b}[39m\u{1b}[32ml\u{1b}[39m\u{1b}[32mo\u{1b}[39m\u{1b}[30;42m \u{1b}[0m\u{1b}[32m你\u{1b}[39m\u{1b}[32m好\u{1b}[39m\n\n", 
+            "\u{1b}[33m-\u{1b}[39m\u{1b}[30;43m \u{1b}[0m\u{1b}[33mH\u{1b}[39m\u{1b}[30;43me\u{1b}[0m\u{1b}[33ml\u{1b}[39m\u{1b}[33ml\u{1b}[39m\u{1b}[33mo\u{1b}[39m\u{1b}[33m你\u{1b}[39m\u{1b}[33m好\u{1b}[39m\u{1b}[30;43m \u{1b}[0m\n\u{1b}[32m+\u{1b}[39m\u{1b}[32mH\u{1b}[39m\u{1b}[30;42ma\u{1b}[0m\u{1b}[32ml\u{1b}[39m\u{1b}[32ml\u{1b}[39m\u{1b}[32mo\u{1b}[39m\u{1b}[30;42m \u{1b}[0m\u{1b}[32m你\u{1b}[39m\u{1b}[32m好\u{1b}[39m\n\n", 
             diff
         );
+
+        let diff = diff_lines_with_err_color(old_str, new_str, Red, on_color_transparent);
+        assert_eq!("\u{1b}[31m-\u{1b}[39m\u{1b}[31m \u{1b}[39m\u{1b}[31mH\u{1b}[39m\u{1b}[31me\u{1b}[39m\u{1b}[31ml\u{1b}[39m\u{1b}[31ml\u{1b}[39m\u{1b}[31mo\u{1b}[39m\u{1b}[31m你\u{1b}[39m\u{1b}[31m好\u{1b}[39m\u{1b}[31m \u{1b}[39m\n\u{1b}[32m+\u{1b}[39m\u{1b}[32mH\u{1b}[39m\u{1b}[32ma\u{1b}[39m\u{1b}[32ml\u{1b}[39m\u{1b}[32ml\u{1b}[39m\u{1b}[32mo\u{1b}[39m\u{1b}[32m \u{1b}[39m\u{1b}[32m你\u{1b}[39m\u{1b}[32m好\u{1b}[39m\n\n", diff);
+
+        let diff = diff_lines_with_err_color(old_str, new_str, Yellow, on_color_transparent);
+        assert_eq!("\u{1b}[33m-\u{1b}[39m\u{1b}[33m \u{1b}[39m\u{1b}[33mH\u{1b}[39m\u{1b}[33me\u{1b}[39m\u{1b}[33ml\u{1b}[39m\u{1b}[33ml\u{1b}[39m\u{1b}[33mo\u{1b}[39m\u{1b}[33m你\u{1b}[39m\u{1b}[33m好\u{1b}[39m\u{1b}[33m \u{1b}[39m\n\u{1b}[32m+\u{1b}[39m\u{1b}[32mH\u{1b}[39m\u{1b}[32ma\u{1b}[39m\u{1b}[32ml\u{1b}[39m\u{1b}[32ml\u{1b}[39m\u{1b}[32mo\u{1b}[39m\u{1b}[32m \u{1b}[39m\u{1b}[32m你\u{1b}[39m\u{1b}[32m好\u{1b}[39m\n\n", diff);
     }
 }
