@@ -34,3 +34,16 @@ def test_lint_for():
     assert line.line == 1
     assert line.col == 5
     assert line.new == "这是 Heading 标题"
+
+def test_load_config():
+    autocorrect.load_config('{ textRules: { "你好hello": 0 } }')
+    assert autocorrect.format("Hello你好.") == "Hello 你好。"
+    assert autocorrect.format("你好hello.") == "你好hello."
+
+def test_ignorer():
+    ignorer = autocorrect.Ignorer("../")
+    assert ignorer.is_ignored("README.md") == True
+    assert ignorer.is_ignored("src/lib.rs") == True
+    assert ignorer.is_ignored("target/foo/bar") == True
+    assert ignorer.is_ignored("Cagro.toml") == False
+    assert ignorer.is_ignored("autocorrect-rb.gemspec") == False
